@@ -177,6 +177,25 @@ class CaseHandler(object):
                     {"phenotype_terms": {"$exists": False}},
                 ]
 
+        if query_field == "exact_dia":
+            if query_term != "":
+                # User might have provided multiple query terms
+                omim_terms = [term for term in query_term.replace(" ", "").split(",")]
+                query["$or"] = [
+                    {
+                        "diagnosis_phenotypes.disease_id": {"$in": omim_terms}
+                    },  # OMIM phenotypes are assigned as a list of dictionaries
+                    {
+                        "diagnosis_phenotypes": {"$in": omim_terms}
+                    },  # old way of saving OMIM terms --> list of ids [616538,611277]
+                ]
+
+            else:  # query for cases with no HPO terms
+                query["$or"] = [
+                    {"diagnosis_phenotypes": {"$size": 0}},
+                    {"diagnosis_phenotypes": {"$exists": False}},
+                ]
+
         if query_field == "synopsis":
             if query_term != "":
                 query["$text"] = {"$search": query_term}
@@ -229,6 +248,7 @@ class CaseHandler(object):
         skip_assigned=False,
         has_causatives=False,
         reruns=False,
+        rerun_monitor=False,
         finished=False,
         research_requested=False,
         is_research=False,
@@ -297,6 +317,9 @@ class CaseHandler(object):
         if reruns:
             query["rerun_requested"] = True
 
+        if rerun_monitor:
+            query["rerun_monitoring"] = True
+
         if status:
             query["status"] = status
 
