@@ -1,5 +1,4 @@
 import logging
-from pprint import pprint as pp
 
 import intervaltree
 from pymongo.errors import BulkWriteError, DuplicateKeyError
@@ -67,13 +66,13 @@ class GeneHandler(object):
         query["hgnc_id"] = hgnc_identifier
         query["build"] = build
 
+        projection["hgnc_id"] = 1
         projection["hgnc_symbol"] = 1
         projection["description"] = 1
         projection["chromosome"] = 1
         projection["start"] = 1
         projection["end"] = 1
 
-        LOG.debug("Fetching gene (light) %s" % hgnc_identifier)
         gene_symbol_obj = self.hgnc_collection.find_one(query, projection)
         if not gene_symbol_obj:
             return None
