@@ -8,6 +8,8 @@ EXPORT_HEADER = [
     "Gene_name",
     "Canonical_transcript/HGVS/protein_change",
     "Primary_transcript/HGVS/protein_change",
+    "CADD",
+    "GnomAD AF",
 ]
 
 MT_EXPORT_HEADER = [
