@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 import logging
-from pprint import pprint as pp
 
 from scout.constants import SO_TERMS
 
 LOG = logging.getLogger(__name__)
 
 
-def parse_transcripts(raw_transcripts, allele=None):
+def parse_transcripts(raw_transcripts):
     """Parse transcript information from VCF variants
 
     Args:
@@ -20,25 +19,13 @@ def parse_transcripts(raw_transcripts, allele=None):
         transcript = {}
         # There can be several functional annotations for one variant
         functional_annotations = entry.get("CONSEQUENCE", "").split("&")
-        transcript["functional_annotations"] = functional_annotations
         # Get the transcript id (ensembl gene id)
-        transcript_id = entry.get("FEATURE", "").split(":")[0]
-        transcript["transcript_id"] = transcript_id
+        transcript["transcript_id"] = entry.get("FEATURE", "").split(":")[0]
 
         # Add the hgnc gene identifiers
         # The HGNC ID is prefered and will be used if it exists
-        hgnc_id = entry.get("HGNC_ID")
-        if hgnc_id:
-            hgnc_id = hgnc_id.split(":")[-1]
-            transcript["hgnc_id"] = int(hgnc_id)
-        else:
-            transcript["hgnc_id"] = None
-
-        hgnc_symbol = entry.get("SYMBOL")
-        if hgnc_symbol:
-            transcript["hgnc_symbol"] = hgnc_symbol
-        else:
-            transcript["hgnc_symbol"] = None
+        transcript["hgnc_id"] = get_hgnc_id(entry)
+        transcript["hgnc_symbol"] = entry.get("SYMBOL")
 
         ########### Fill it with the available information ###########
 
@@ -48,26 +35,10 @@ def parse_transcripts(raw_transcripts, allele=None):
         transcript["protein_id"] = entry.get("ENSP")
 
         ## Polyphen prediction ##
-        polyphen_prediction = entry.get("POLYPHEN")
-        # Default is 'unknown'
-        prediction_term = "unknown"
-        if polyphen_prediction:
-            prediction_term = polyphen_prediction.split("(")[0]
-        transcript["polyphen_prediction"] = prediction_term
+        transcript["polyphen_prediction"] = get_polyphen_prediction(entry)
 
         ## Sift prediction ##
-        # Check with other key if it does not exist
-        sift_prediction = entry.get("SIFT")
-        # Default is 'unknown'
-        prediction_term = "unknown"
-
-        if not sift_prediction:
-            sift_prediction = entry.get("SIFT_PRED")
-
-        if sift_prediction:
-            prediction_term = sift_prediction.split("(")[0]
-
-        transcript["sift_prediction"] = prediction_term
+        transcript["sift_prediction"] = get_sift_prediction(entry)
 
         if entry.get("REVEL_RANKSCORE"):
             transcript["revel"] = float(entry.get("REVEL_RANKSCORE"))
@@ -96,42 +67,14 @@ def parse_transcripts(raw_transcripts, allele=None):
                 elif domain_name == "SMART_domains":
                     transcript["smart_domain"] = domain_id
 
-        coding_sequence_entry = entry.get("HGVSC", "").split(":")
-        protein_sequence_entry = entry.get("HGVSP", "").split(":")
-
-        coding_sequence_name = None
-        if len(coding_sequence_entry) > 1:
-            coding_sequence_name = coding_sequence_entry[-1]
-
-        transcript["coding_sequence_name"] = coding_sequence_name
-
-        protein_sequence_name = None
-        if len(protein_sequence_entry) > 1:
-            protein_sequence_name = protein_sequence_entry[-1]
-
-        transcript["protein_sequence_name"] = protein_sequence_name
-
+        transcript["coding_sequence_name"] = get_coding_sequence(entry)
+        transcript["protein_sequence_name"] = get_protein_sequence(entry)
         transcript["biotype"] = entry.get("BIOTYPE")
-
         transcript["exon"] = entry.get("EXON")
         transcript["intron"] = entry.get("INTRON")
-
-        if entry.get("STRAND"):
-            if entry["STRAND"] == "1":
-                transcript["strand"] = "+"
-            elif entry["STRAND"] == "-1":
-                transcript["strand"] = "-"
-        else:
-            transcript["strand"] = None
-
-        functional = []
-        regional = []
-        for annotation in functional_annotations:
-            functional.append(annotation)
-            regional.append(SO_TERMS[annotation]["region"])
-
-        transcript["functional_annotations"] = functional
-        transcript["region_annotations"] = regional
+        transcript["strand"] = get_strand(entry)
+        transcript["functional_annotations"] = functional_annotations
+        transcript["region_annotations"] = get_regional_annotation(functional_annotations)
 
         # Check if the transcript is marked cannonical by vep
         transcript["is_canonical"] = entry.get("CANONICAL") == "YES"
@@ -163,59 +106,7 @@ def parse_transcripts(raw_transcripts, allele=None):
         if entry.get("GNOMAD_MT_AF_HET", "") != "":
             transcript["gnomad_mt_heteroplasmic"] = float(entry.get("GNOMAD_MT_AF_HET"))
 
-        # Check frequencies
-        # There are different keys for different versions of VEP
-        # We only support version 90+
-        thousandg_freqs = []
-        gnomad_freqs = []
-        try:
-            # The keys for VEP v90+:
-            # 'AF' or '1000GAF' - 1000G all populations combined
-            # 'xxx_AF' - 1000G (or NHLBI-ESP) individual populations
-            # 'gnomAD_AF' - gnomAD exomes, all populations combined
-            # 'gnomAD_xxx_AF' - gnomAD exomes, individual populations
-            # 'MAX_AF' - Max of all populations (1000G, gnomAD exomes, ESP)
-            # https://www.ensembl.org/info/docs/tools/vep/vep_formats.html
-
-            # Loop over all keys to find frequency entries
-            for key in entry:
-                # All frequencies endswith AF
-                if not key.endswith("AF"):
-                    continue
-
-                value = entry[key]
-                if not value:
-                    continue
-
-                # This is the 1000G max af information
-                if key == "AF" or key == "1000GAF":
-                    transcript["thousand_g_maf"] = float(value)
-                    continue
-
-                if key == "GNOMAD_AF":
-                    transcript["gnomad_maf"] = float(value)
-                    continue
-
-                if key == "EXAC_MAX_AF":
-                    transcript["exac_max"] = float(value)
-                    transcript["exac_maf"] = float(value)
-                    continue
-
-                if "GNOMAD" in key:
-                    gnomad_freqs.append(float(value))
-
-                else:
-                    thousandg_freqs.append(float(value))
-
-            if thousandg_freqs:
-                transcript["thousandg_max"] = max(thousandg_freqs)
-
-            if gnomad_freqs:
-                transcript["gnomad_max"] = max(gnomad_freqs)
-
-        except Exception as err:
-            LOG.debug("Something went wrong when parsing frequencies")
-            LOG.debug("Only splitted and normalised VEP v90+ is supported")
+        set_variant_frequencies(transcript, entry)
 
         if entry.get("CLINVAR_CLNVID"):
             transcript["clinvar_clnvid"] = entry["CLINVAR_CLNVID"]
@@ -226,21 +117,8 @@ def parse_transcripts(raw_transcripts, allele=None):
         if clnsig:
             transcript["clnsig"] = clnsig.split("&")
 
-        transcript["dbsnp"] = []
-        transcript["cosmic"] = []
-        variant_ids = entry.get("EXISTING_VARIATION")
-
-        if variant_ids:
-            for variant_id in variant_ids.split("&"):
-                if variant_id.startswith("rs"):
-                    transcript["dbsnp"].append(variant_id)
-                elif variant_id.startswith("COSM") or variant_id.startswith("COSV"):
-                    transcript["cosmic"].append(variant_id)
-
-        cosmic_ids = entry.get("COSMIC")
-        if cosmic_ids:
-            for cosmic_id in cosmic_ids.split("&"):
-                transcript["cosmic"].append(cosmic_id)
+        transcript["dbsnp"] = get_dbsnp_list(entry)
+        transcript["cosmic"] = get_cosmic_list(entry)
 
         yield transcript
 
@@ -312,3 +190,153 @@ def parse_transcripts_spliceai(transcript, entry):
     transcript["spliceai_delta_score"] = spliceai_delta_score
     transcript["spliceai_delta_position"] = spliceai_delta_position
     transcript["spliceai_prediction"] = spliceai_prediction
+
+
+def get_strand(entry):
+    """Get string from transcript"""
+    if entry.get("STRAND") == "1":
+        return "+"
+    if entry.get("STRAND") == "-1":
+        return "-"
+    return None
+
+
+def get_protein_sequence(entry):
+    """Get HGVSP from entry"""
+    return get_sequence_aux(entry, "HGVSP")
+
+
+def get_coding_sequence(entry):
+    """Get HGVSC from entry"""
+    return get_sequence_aux(entry, "HGVSC")
+
+
+def get_sequence_aux(entry, name):
+    """Auxiliary function will extract name form entry"""
+    sequence_entry = entry.get(name, "").split(":")
+    if len(sequence_entry) > 1:
+        return sequence_entry[-1]
+    return None
+
+
+def get_hgnc_id(entry):
+    """"""
+    hgnc_id = entry.get("HGNC_ID")
+    if hgnc_id:
+        hgnc_id = hgnc_id.split(":")[-1]
+        return int(hgnc_id)
+    return None
+
+
+def get_polyphen_prediction(entry):
+    """Get polyphen prediction, return default 'unknown' if not found"""
+    polyphen_prediction = entry.get("POLYPHEN")
+    if polyphen_prediction:
+        return polyphen_prediction.split("(")[0]
+    return "unknown"
+
+
+def get_sift_prediction(entry):
+    """Get SIFT prediction from entry. Sorting Intolerant From Tolerant."""
+
+    sift_prediction = entry.get("SIFT")
+    if not sift_prediction:
+        sift_prediction = entry.get("SIFT_PRED")
+    if sift_prediction:
+        return sift_prediction.split("(")[0]
+    return "unknown"
+
+
+def get_dbsnp_list(entry):
+    """Get dbSNP -the NCBI database of genetic variation- data if present in entry."""
+    dbsnp_list = []
+    variant_ids = entry.get("EXISTING_VARIATION")
+
+    if variant_ids:
+        for variant_id in variant_ids.split("&"):
+            if variant_id.startswith("rs"):
+                dbsnp_list.append(variant_id)
+    return dbsnp_list
+
+
+def get_cosmic_list(entry):
+    """Get COSMIC -Catalogue Of Somatic Mutations In Cancer- if present in entry."""
+    cosmic_list = []
+    variant_ids = entry.get("EXISTING_VARIATION")
+
+    if variant_ids:
+        for variant_id in variant_ids.split("&"):
+            if variant_id.startswith("COSM") or variant_id.startswith("COSV"):
+                cosmic_list.append(variant_id)
+
+    cosmic_ids = entry.get("COSMIC")
+    if cosmic_ids:
+        for cosmic_id in cosmic_ids.split("&"):
+            cosmic_list.append(cosmic_id)
+
+    return cosmic_list
+
+
+def get_regional_annotation(functional_annotations):
+    """Get regional annotation from SO TERM"""
+    regional_list = []
+    for annotation in functional_annotations:
+        regional_list.append(SO_TERMS[annotation]["region"])
+    return regional_list
+
+
+def set_variant_frequencies(transcript, entry):
+    """Set variant frequencies found in entry. There are different keys
+    for different versions of VEP. Currently only supports version 90+.
+
+    The keys for VEP v90+:
+    * 'AF' or '1000GAF' - 1000G all populations combined
+    * 'xxx_AF' - 1000G (or NHLBI-ESP) individual populations
+    * 'gnomAD_AF' - gnomAD exomes, all populations combined
+    * 'gnomAD_xxx_AF' - gnomAD exomes, individual populations
+    * 'MAX_AF' - Max of all populations (1000G, gnomAD exomes, ESP)
+
+    Reference: https://www.ensembl.org/info/docs/tools/vep/vep_formats.html
+    """
+
+    thousandg_freqs = []
+    gnomad_freqs = []
+    try:
+        for key in entry:
+            # All frequencies endswith AF
+            if not key.endswith("AF"):
+                continue
+
+            value = entry[key]
+            if not value:
+                continue
+
+            # This is the 1000G max af information
+            if key == "AF" or key == "1000GAF":
+                transcript["thousand_g_maf"] = float(value)
+                continue
+
+            if key == "GNOMAD_AF":
+                transcript["gnomad_maf"] = float(value)
+                continue
+
+            if key == "EXAC_MAX_AF":
+                transcript["exac_max"] = float(value)
+                transcript["exac_maf"] = float(value)
+                continue
+
+            if "GNOMAD" in key:
+                gnomad_freqs.append(float(value))
+
+            else:
+                thousandg_freqs.append(float(value))
+
+        if thousandg_freqs:
+            transcript["thousandg_max"] = max(thousandg_freqs)
+
+        if gnomad_freqs:
+            transcript["gnomad_max"] = max(gnomad_freqs)
+
+    except Exception as err:
+        LOG.warning("Failed to parse variant frequencies")
+        LOG.warning("Only splitted and normalised VEP v90+ is supported")
