@@ -280,7 +280,7 @@ def parse_variant(
     parsed_transcripts = []
     dbsnp_ids = set()
     cosmic_ids = set()
-    for parsed_transcript in parse_transcripts(raw_transcripts, parsed_variant["alternative"]):
+    for parsed_transcript in parse_transcripts(raw_transcripts):
         parsed_transcripts.append(parsed_transcript)
         for dbsnp in parsed_transcript.get("dbsnp", []):
             dbsnp_ids.add(dbsnp)
@@ -331,15 +331,21 @@ def parse_variant(
 
     parsed_variant["frequencies"] = frequencies
 
-    # parse out old local observation count
-    local_obs_old = variant.INFO.get("Obs")
+    # SNVs contain INFO field Obs, SVs contain clinical_genomics_loqusObs
+    local_obs_old = variant.INFO.get("Obs") or variant.INFO.get("clinical_genomics_loqusObs")
     if local_obs_old:
         parsed_variant["local_obs_old"] = int(local_obs_old)
 
+    # SNVs only
     local_obs_hom_old = variant.INFO.get("Hom")
     if local_obs_hom_old:
         parsed_variant["local_obs_hom_old"] = int(local_obs_hom_old)
 
+    # SVs only
+    local_obs_old_freq = variant.INFO.get("clinical_genomics_loqusFrq")
+    if local_obs_old_freq:
+        parsed_variant["local_obs_old_freq"] = float(local_obs_old_freq)
+
     ###################### Add severity predictions ######################
     cadd = parse_cadd(variant, parsed_transcripts)
     if cadd:
