@@ -24,6 +24,7 @@ from scout.constants import (
     MT_EXPORT_HEADER,
     PHENOTYPE_GROUPS,
     PHENOTYPE_MAP,
+    SAMPLE_SOURCE,
     SEX_MAP,
     VARIANT_REPORT_VARIANT_FEATURES,
     VERBS_MAP,
@@ -39,7 +40,7 @@ from scout.export.variant import export_mt_variants
 from scout.parse.matchmaker import genomic_features, hpo_terms, omim_terms, parse_matches
 from scout.server.blueprints.variant.controllers import variant as variant_decorator
 from scout.server.blueprints.variants.controllers import get_manual_assessments
-from scout.server.extensions import RerunnerError, matchmaker, rerunner, store
+from scout.server.extensions import RerunnerError, gens, matchmaker, rerunner, store
 from scout.server.utils import institute_and_case
 from scout.utils.scout_requests import delete_request_json, post_request_json
 
@@ -51,6 +52,8 @@ JSON_HEADERS = {
     "Accept": "text/json",
 }
 
+COVERAGE_REPORT_TIMEOUT = 20
+
 
 def coverage_report_contents(base_url, institute_obj, case_obj):
     """Capture the contents of a case coverage report (chanjo-report), to be displayed in the general case report
@@ -86,7 +89,13 @@ def coverage_report_contents(base_url, institute_obj, case_obj):
     request_data["level"] = institute_obj.get("coverage_cutoff", 15)
 
     # Collect the coverage report HTML string
-    resp = requests.post(base_url + "reports/report", data=request_data)
+    try:
+        resp = requests.post(
+            base_url + "reports/report", timeout=COVERAGE_REPORT_TIMEOUT, data=request_data
+        )
+    except requests.Timeout:
+        html_body_content = "<span><b>Coverage report unavailable</b></span>"
+        return html_body_content
 
     # Extract the contents between <body> and </body>
     html_body_content = resp.text.split("<body>")[1].split("</body>")[0]
@@ -253,8 +262,17 @@ def case(store, institute_obj, case_obj):
     # Phenotype groups can be specific for an institute, there are some default groups
     pheno_groups = institute_obj.get("phenotype_groups") or PHENOTYPE_GROUPS
 
-    # complete OMIM diagnoses specific for this case
-    omim_terms = {term["disease_nr"]: term for term in store.case_omim_diagnoses(case_obj)}
+    # If case diagnoses are a list of integers, convert into a list of dictionaries
+    omim_terms = {}
+    case_diagnoses = case_obj.get("diagnosis_phenotypes", [])
+    if case_diagnoses:
+        if isinstance(case_diagnoses[0], int):
+            case_obj = store.convert_diagnoses_format(case_obj)
+        # Fetch complete OMIM diagnoses specific for this case
+        omim_terms = {
+            term["disease_id"]: term
+            for term in store.case_omim_diagnoses(case_obj.get("diagnosis_phenotypes"))
+        }
 
     if case_obj.get("custom_images"):
         # re-encode images as base64
@@ -265,6 +283,8 @@ def case(store, institute_obj, case_obj):
                 img["data"] = b64encode(img["data"]).decode("utf-8")
 
     data = {
+        "institute": institute_obj,
+        "case": case_obj,
         "status_class": STATUS_MAP.get(case_obj["status"]),
         "other_causatives": [var for var in store.check_causatives(case_obj=case_obj)],
         "managed_variants": [var for var in store.check_managed(case_obj=case_obj)],
@@ -282,6 +302,10 @@ def case(store, institute_obj, case_obj):
         "omim_terms": omim_terms,
         "manual_rank_options": MANUAL_RANK_OPTIONS,
         "cancer_tier_options": CANCER_TIER_OPTIONS,
+        "tissue_types": SAMPLE_SOURCE,
+        "mme_nodes": matchmaker.connected_nodes,
+        "gens_info": gens.connection_settings(case_obj.get("genome_build")),
+        "display_rerunner": rerunner.connection_settings.get("display", False),
     }
 
     return data
@@ -388,7 +412,6 @@ def case_report_variants(store, case_obj, institute_obj, data):
                 add_case=False,
                 add_other=False,
                 get_overlapping=False,
-                add_compounds=False,
                 variant_type=var_obj["category"],
                 institute_obj=institute_obj,
                 case_obj=case_obj,
