@@ -19,9 +19,10 @@ from scout.constants import (
     MOSAICISM_OPTIONS,
     VERBS_MAP,
 )
+from scout.parse.clinvar import set_submission_objects
 from scout.server.blueprints.variant.utils import update_representative_gene
 from scout.server.extensions import cloud_tracks, gens
-from scout.server.links import ensembl, get_variant_links
+from scout.server.links import get_variant_links
 from scout.server.utils import (
     case_append_alignments,
     institute_and_case,
@@ -164,7 +165,6 @@ def variant(
     add_case=True,
     add_other=True,
     get_overlapping=True,
-    add_compounds=True,
     variant_category=None,
     variant_type=None,
     case_obj=None,
@@ -535,6 +535,50 @@ def variant_acmg_post(store, institute_id, case_name, variant_id, user_email, cr
     return classification
 
 
+def build_clinvar_submission(store, request, institute_id, case_name, variant_id):
+    """Add some variants to a ClinVar submission object or create a new ClinVar submission
+
+    Args:
+        store(scout.adapter.MongoAdapter)
+        request(flask.Request)
+        institute_id(str): institute_obj['_id']
+        case_name(str): case_obj['display_name']
+        variant_id(str): variant_obj['document_id']
+    """
+    form_dict = {}
+
+    # flatten up HPO and OMIM terms lists into string of keys separated by semicolon
+    for key, value in request.form.items():
+        if "@" in key:
+            variant_id = key.split("@")[1]
+
+        if key.startswith("hpo_terms") and f"omim_terms@{variant_id}" not in request.form:
+            form_dict["@".join(["condition_id_type", variant_id])] = "HPO"
+            form_dict["@".join(["condition_id_value", variant_id])] = ";".join(
+                request.form.getlist(key)
+            )
+
+        elif key.startswith("omim_terms"):
+            form_dict["@".join(["condition_id_type", variant_id])] = "OMIM"
+            form_dict["@".join(["condition_id_value", variant_id])] = ";".join(
+                request.form.getlist(key)
+            )
+
+        elif key.startswith("clin_features"):
+            form_dict[key] = ";".join(request.form.getlist(key))
+
+        else:
+            form_dict[key] = value
+
+    # A tuple of submission objects (variants and casedata objects):
+    submission_objects = set_submission_objects(form_dict)
+
+    # Add submission data to an open clinvar submission object,
+    # or create a new if no open submission is found in database
+    open_submission = store.get_open_clinvar_submission(institute_id)
+    updated_submission = store.add_to_submission(open_submission["_id"], submission_objects)
+
+
 def clinvar_export(store, institute_id, case_name, variant_id):
     """Gather the required data for creating the clinvar submission form
 
@@ -550,6 +594,10 @@ def clinvar_export(store, institute_id, case_name, variant_id):
 
     """
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    # If case diagnoses are a list of integers, convert into a list of dictionaries
+    case_diagnoses = case_obj.get("diagnosis_phenotypes", [])
+    if case_diagnoses and isinstance(case_diagnoses[0], int):
+        case_obj = store.convert_diagnoses_format(case_obj)
     pinned = [
         store.variant(variant_id) or variant_id for variant_id in case_obj.get("suspects", [])
     ]
