@@ -3,7 +3,6 @@
 from authlib.integrations.flask_client import OAuth
 from flask_bootstrap import Bootstrap
 from flask_debugtoolbar import DebugToolbarExtension
-from flask_ldap3_login import LDAP3LoginManager
 from flask_login import LoginManager
 from flask_mail import Mail
 
@@ -11,6 +10,7 @@ from scout.adapter import MongoAdapter
 from scout.utils.cloud_resources import AlignTrackHandler
 
 from .gens_extension import GensViewer
+from .ldap_extension import LdapManager
 from .loqus_extension import LoqusDB
 from .matchmaker_extension import MatchMaker
 from .mongo_extension import MongoDB
@@ -20,7 +20,7 @@ toolbar = DebugToolbarExtension()
 bootstrap = Bootstrap()
 store = MongoAdapter()
 login_manager = LoginManager()
-ldap_manager = LDAP3LoginManager()
+ldap_manager = LdapManager()
 oauth_client = OAuth()
 mail = Mail()
 loqusdb = LoqusDB()
