@@ -1,10 +1,10 @@
-from pprint import pprint as pp
-
 from flask import current_app
 
 from scout.constants import SPIDEX_HUMAN
 from scout.utils.convert import amino_acid_residue_change_3_to_1
 
+SHALLOW_REFERENCE_STR_LOCI = ["ARX", "HOXA13"]
+
 
 def add_gene_links(gene_obj, build=37):
     """Update a gene object with links
@@ -63,6 +63,40 @@ def add_gene_links(gene_obj, build=37):
     gene_obj["cbioportal_link"] = cbioportal_gene(hgnc_symbol)
     gene_obj["civic_link"] = civic_gene(hgnc_symbol)
     gene_obj["iarctp53_link"] = iarctp53(hgnc_symbol)
+    gene_obj["stripy_link"] = stripy_gene(hgnc_symbol)
+    gene_obj["gnomad_str_link"] = gnomad_str_gene(hgnc_symbol)
+    gene_obj["panelapp_link"] = panelapp_gene(hgnc_symbol)
+
+
+def panelapp_gene(hgnc_symbol):
+    link = "https://panelapp.genomicsengland.co.uk/panels/entities/{}"
+
+    if not hgnc_symbol:
+        return None
+    return link.format(hgnc_symbol)
+
+
+def stripy_gene(hgnc_symbol):
+    link = "https://stripy.org/database/{}"
+
+    if not hgnc_symbol:
+        return None
+
+    if hgnc_symbol in SHALLOW_REFERENCE_STR_LOCI:
+        return "https://stripy.org/database"
+    return link.format(hgnc_symbol)
+
+
+def gnomad_str_gene(hgnc_symbol):
+    link = "https://gnomad.broadinstitute.org/short-tandem-repeat/{}?dataset=gnomad_r3"
+
+    if not hgnc_symbol:
+        return None
+
+    if hgnc_symbol in SHALLOW_REFERENCE_STR_LOCI:
+        return "https://gnomad.broadinstitute.org/short-tandem-repeats?dataset=gnomad_r3"
+
+    return link.format(hgnc_symbol)
 
 
 def civic_gene(hgnc_symbol):
